@@ -32,6 +32,10 @@
 #' Third, after pressing Enter, R will try to open a browser window to sign the token. If 
 #' everything works well, you will get a message that says you can return to R. If not,
 #' try again in a few minutes to make sure your app had its settings updated properly.
+#'
+#' Note that the authentication process will NOT work correctly in RStudio. As an
+#' alternative, create your token in R from the command line interface or the R
+#' application, save it as a file, and then open it up from RStudio.
 #' 
 #'
 #' @author
@@ -47,8 +51,9 @@
 #' @param extended_permissions If \code{TRUE}, the token will give access to some of
 #' the authenticated user's private information (birthday, hometown, location,
 #' relationships) and that of his/her friends, and permissions to post
-#' status updates. If \code{FALSE}, token will give access only to public information.
-#' Note that \code{updateStatus} will only work for tokens with extended permissions.
+#' status updates as well as to access checkins, likes, and the user's newsfeed. 
+#' If \code{FALSE}, token will give access only to public information. Note 
+#' that \code{updateStatus} will only work for tokens with extended permissions.
 #'
 #' @examples \dontrun{
 #' ## an example of an authenticated request after creating the OAuth token
@@ -83,7 +88,9 @@ fbOAuth <- function(app_id, app_secret, extended_permissions=TRUE)
 	myapp <- oauth_app("facebook", app_id, app_secret)
 	if (extended_permissions==TRUE){
 		scope <- paste("user_birthday,user_hometown,user_location,user_relationships,",
-			"friends_birthday,friends_hometown,friends_location,friends_relationships,publish_actions", collapse="")
+			"friends_birthday,friends_hometown,friends_location,friends_relationships,publish_actions,",
+			"user_status,user_checkins,friends_status,friends_checkins,user_likes,friends_likes,read_stream,export_stream", 
+			collapse="")
 	}
 	else { scope <- NULL}
 	facebook_token <- oauth2.0_token(facebook, myapp,
